@@ -2,22 +2,25 @@ import os
 import typing
 
 import wialon.api
-from loguru import logger
 
-from . import flags as wialon_flags
 
-logger.disable(__name__)
+class WialonAPIError(Exception):
+    def __init__(self, message, *args, **kwargs) -> None:
+        self.message = message
+        self._code = int(message._code)
+        super().__init__(message, *args, **kwargs)
+
+    @property
+    def code(self) -> int:
+        return self._code
 
 
 class Wialon(wialon.api.Wialon):
-    def call(self, action_name: str, *argc, **kwargs) -> dict[str, typing.Any]:
+    def call(self, *argc, **kwargs) -> dict[str, typing.Any]:
         try:
-            result = super().call(action_name, *argc, **kwargs)
-            logger.debug("Successfully executed '{}'", action_name)
-            return result
+            return super().call(*argc, **kwargs)
         except wialon.api.WialonError as e:
-            logger.warning("Failed to execute '{}': '{}'", action_name, e)
-            return {}
+            raise WialonAPIError(e)
 
 
 class WialonSession:
@@ -49,9 +52,6 @@ class WialonSession:
 
         self._token = token or os.getenv("WIALON_TOKEN")
         self._username = None
-        self._gis_sid = None
-        self._hw_gp_ip = None
-        self._wsdk_version = None
         self._uid = None
         self._wialon_api = Wialon(
             scheme=scheme, host=host, port=port, sid=sid, token=self.token
@@ -90,28 +90,6 @@ class WialonSession:
     def wialon_api(self) -> Wialon:
         return self._wialon_api
 
-    @property
-    def host(self) -> str | None:
-        """
-        IP of the client hosting the Wialon session.
-
-        :type: :py:obj:`str` | :py:obj:`None`
-        :value: :py:obj:`None`
-
-        """
-        return self._host
-
-    @property
-    def wsdk_version(self) -> str | None:
-        """
-        The Wialon Source Developer Kit (WSDK) version number of the session.
-
-        :type: :py:obj:`str` | :py:obj:`None`
-        :value: :py:obj:`None`
-
-        """
-        return self._wsdk_version
-
     @property
     def uid(self) -> str | None:
         """
@@ -173,18 +151,14 @@ class WialonSession:
         :rtype: :py:obj:`str`
 
         """
-        if flags is None:
-            flags = (
-                wialon_flags.TokenFlag.ONLINE_TRACKING
-                | wialon_flags.TokenFlag.VIEW_ACCESS
-                | wialon_flags.TokenFlag.MANAGE_NONSENSITIVE
-            )
         try:
-            response = self.wialon_api.token_login(**{"token": token, "fl": flags})
+            response = self.wialon_api.token_login(
+                **{"token": token, "fl": flags if flags else 0x2}
+            )
             self._set_login_response(response)
             return response.get("eid", "")
         except (wialon.api.WialonError, ValueError):
-            logger.critical("Failed to login to the Wialon API.")
+            print("Failed to login to the Wialon API.")
             raise
 
     def logout(self) -> None:
@@ -199,10 +173,8 @@ class WialonSession:
         response = self.wialon_api.core_logout({})
 
         if response.get("error") != 0:
-            logger.warning(
-                "Failed to properly logout of session #{}: '{}'",
-                sid,
-                response.get("message"),
+            print(
+                f"Failed to properly logout of session #{sid}: '{response.get('message')}'"
             )
         self.wialon_api.sid = None
 
@@ -221,8 +193,5 @@ class WialonSession:
             raise ValueError(f"Login response is required, got '{login_response}'")
 
         self.wialon_api.sid = login_response.get("eid")
-        self._host = login_response.get("host")
         self._uid = login_response.get("user", {}).get("id")
-        self._nm = login_response.get("user", {}).get("nm")
         self._username = login_response.get("au")
-        self._wsdk_version = login_response.get("wsdk_version")
